[Cmake-commits] CMake branch, master, updated. v3.11.1-516-g4591cdd

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  4591cdd72c83cbb458659d731b87e6b842fae956 (commit)
  from  6774e9cabfb1a9676b787be26cd120e88d6fc21a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4591cdd72c83cbb458659d731b87e6b842fae956
commit 4591cdd72c83cbb458659d731b87e6b842fae956
Author: Kitware Robot <kwro...@kitware.com>
AuthorDate: Wed Apr 18 00:01:05 2018 -0400
Commit: Kitware Robot <kwro...@kitware.com>
CommitDate: Wed Apr 18 00:01:05 2018 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index e7dc51e..d5174c4 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 11)
-set(CMake_VERSION_PATCH 20180417)
+set(CMake_VERSION_PATCH 20180418)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake-developers


[Cmake-commits] CMake branch, master, updated. v3.11.1-513-g80d4946

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  80d49468de07d194576ead24ff6f2999e1fe32e6 (commit)
   via  fbf330ce2b619193c22d357e01040bf1de74f053 (commit)
  from  12139ad009930ba00c650c03e11f4eff3a081839 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=80d49468de07d194576ead24ff6f2999e1fe32e6
commit 80d49468de07d194576ead24ff6f2999e1fe32e6
Merge: 12139ad fbf330c
Author: Brad King 
AuthorDate: Tue Apr 17 17:19:14 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 13:19:20 2018 -0400

Merge topic 'typo-incerment'

fbf330ce2b typo: incerment -> increment

Acked-by: Kitware Robot 
Merge-request: !1977


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fbf330ce2b619193c22d357e01040bf1de74f053
commit fbf330ce2b619193c22d357e01040bf1de74f053
Author: Rolf Eike Beer 
AuthorDate: Tue Apr 17 18:52:01 2018 +0200
Commit: Rolf Eike Beer 
CommitDate: Tue Apr 17 18:52:01 2018 +0200

typo: incerment -> increment

diff --git a/Help/command/list.rst b/Help/command/list.rst
index 9451d31..e240b65 100644
--- a/Help/command/list.rst
+++ b/Help/command/list.rst
@@ -213,7 +213,7 @@ The  may be one of:
 
   list(TRANSFORM   AT  [ ...] ...)
 
-``FOR``: Specify a range with, optionaly, an incerment used to iterate over
+``FOR``: Specify a range with, optionaly, an increment used to iterate over
 the range. ::
 
   list(TRANSFORM   FOR   [] ...)

---

Summary of changes:
 Help/command/list.rst |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


[cmake-developers] [ANNOUNCE] CMake 3.11.1 available for download

2018-04-17 Thread Robert Maynard
We are pleased to announce that CMake 3.11.1 is now available for download.

Please use the latest release from our download page:
  https://cmake.org/download/

Thanks for your support!

-
Changes in 3.11.1 since 3.11.0:

Brad King (5):
  Revert "CheckIncludeFiles: Honor CMAKE_REQUIRED_LIBRARIES"
  CPack: Fix crash on invalid generator name
  Restore support for explicitly referenced CMakeLists.txt sources
  Exclude "libgcc_eh" library files from implicit link libraries
  CMake 3.11.1

Daniel Filipe (1):
  Features: Record for VS 2017 through 15.6

Kirill Erofeev (2):
  Explicitly require LibUV 1.10 or higher to build CMake
  bootstrap: Add option to enable/disable usage of system libuv

R2RT (1):
  Fix crash with --trace-expand --warn-uninitialized together

Roland Schulz (1):
  FindOpenMP: Fix support for Intel on Windows

Sebastian Holtermann (7):
  Autogen: Protected calls to cmSystemTools::CollapseCombinedPath
  Autogen: Protected calls to cmSystemTools::Split/JoinPath
  Autogen: Protected calls to cmSystemTools::GetFilenameWithoutLastExtension
  Autogen: Protected calls to cmQtAutoGen::SubDirPrefix
  Autogen: Protected calls to cmFilePathChecksum
  Autogen: Use std::istreambuf_iterator for file so string reading
  Autogen: Print moc/uic/rcc output to stdout
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake-developers


[CMake] [ANNOUNCE] CMake 3.11.1 available for download

2018-04-17 Thread Robert Maynard
We are pleased to announce that CMake 3.11.1 is now available for download.

Please use the latest release from our download page:
  https://cmake.org/download/

Thanks for your support!

-
Changes in 3.11.1 since 3.11.0:

Brad King (5):
  Revert "CheckIncludeFiles: Honor CMAKE_REQUIRED_LIBRARIES"
  CPack: Fix crash on invalid generator name
  Restore support for explicitly referenced CMakeLists.txt sources
  Exclude "libgcc_eh" library files from implicit link libraries
  CMake 3.11.1

Daniel Filipe (1):
  Features: Record for VS 2017 through 15.6

Kirill Erofeev (2):
  Explicitly require LibUV 1.10 or higher to build CMake
  bootstrap: Add option to enable/disable usage of system libuv

R2RT (1):
  Fix crash with --trace-expand --warn-uninitialized together

Roland Schulz (1):
  FindOpenMP: Fix support for Intel on Windows

Sebastian Holtermann (7):
  Autogen: Protected calls to cmSystemTools::CollapseCombinedPath
  Autogen: Protected calls to cmSystemTools::Split/JoinPath
  Autogen: Protected calls to cmSystemTools::GetFilenameWithoutLastExtension
  Autogen: Protected calls to cmQtAutoGen::SubDirPrefix
  Autogen: Protected calls to cmFilePathChecksum
  Autogen: Use std::istreambuf_iterator for file so string reading
  Autogen: Print moc/uic/rcc output to stdout
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, release, updated. v3.11.1

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, release has been updated
   via  fbe6cd1596bf280edd49aeb8f981f99d7cd8beb3 (commit)
  from  d1d43a6dbf41b3f9841e96c01c7894b050db0cf2 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


[Cmake-commits] CMake annotated tag, v3.11.1, created. v3.11.1

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The annotated tag, v3.11.1 has been created
at  f07c1daa4c80f28bb282ac4d32ce1daf6e00e95c (tag)
   tagging  fbe6cd1596bf280edd49aeb8f981f99d7cd8beb3 (commit)
  replaces  v3.11.0
 tagged by  Brad King
on  Tue Apr 17 09:43:55 2018 -0400

- Log -
CMake 3.11.1
-BEGIN PGP SIGNATURE-

iQJKBAABCgA0FiEExsJlMku+vcNQtRPQLSzvEDSSFoQFAlrV+hsWHGJyYWQua2lu
Z0BraXR3YXJlLmNvbQAKCRAtLO8QNJIWhPU5D/9x6F+2U/qH4Dwbs2eO7On0ANyX
AkmHP4IOImKFeEdfeooDh2jg6f+D1jMROcUti0UAvTMUnQr3lWavEn4z/Uy6xWUk
EItm52MKlUdgT1EQfDWshFoE9RCvhNA/1cPIpu26HI9fZr4jBxnmjrjSJ5bdvjDU
KD33ys2HS/Kmpd0aI2B+NGehTDBB7B/POdyzBhEp+lCsKdNzK6fiaIQZ5FvO8vCp
noqUDMnTljYX28OnDUAenbNhuwctaYJRrx+vqrqmzxnbc7yXbd2CGgqr8hSbl7HG
cbu6XcJoXTwqnO5b1fYtokW7uKurozh7W2jrhyxQzGsDprWHLe9CCSKW3ohBDO+q
+QbyhLSiexYFGS2qdOUVbOgdakQy6xX1hiYuA/OWMpwD6sM94ch6/dj0TPKt9XK4
EhRuqvjbKaI9oMY6w8I/iTsu68hEE8gk5UmK77zORLDAVbLa7ez5Wk2UzezhNObS
YREw5bUF0B/Jnj4P3183Emxj1OC30T0e7veO5VY06GvUQsWcA+3L1nk4gw6785wA
5/sL270oAJ/SkIpO43prplsjN+l9k3JnoSCl3qtCw9sc7xY3/HQykIknXxtb/RKf
MnW5EJT3D1iTdGrX6bJgc2zotzKLH5ui/ClaVpWAgsfZuPU5/Fu74sjw/kQaDrft
zElE2SWOERrwDKXoTQ==
=b4x8
-END PGP SIGNATURE-

Brad King (15):
  Merge branch 'autogen-protect-cmsys-calls' into release-3.11
  Revert "CheckIncludeFiles: Honor CMAKE_REQUIRED_LIBRARIES"
  Merge branch 'revert-CheckIncludeFile-required-libs' into release-3.11
  Merge branch 'fix-crash-trace-exp-uninit-vars' into release-3.11
  CPack: Fix crash on invalid generator name
  Merge branch 'cpack-trace-nullptr' into release-3.11
  Merge branch 'features-msvc-2017' into release-3.11
  Restore support for explicitly referenced CMakeLists.txt sources
  Merge branch 'backport-fix-explicit-CMakeLists.txt' into release-3.11
  Merge branch 'libuv_version_bump' into release-3.11
  Exclude "libgcc_eh" library files from implicit link libraries
  Merge branch 'implicit-lib-gcceh-file' into release-3.11
  Merge branch 'FindOpenMP-Intel-Windows' into release-3.11
  Merge branch 'bootstrap_system_libuv_option' into release-3.11
  CMake 3.11.1

Daniel Filipe (1):
  Features: Record for VS 2017 through 15.6

ErofeevK (1):
  Explicitly require LibUV 1.10 or higher to build CMake

Kirill Erofeev (1):
  bootstrap: Add option to enable/disable usage of system libuv

R2RT (1):
  Fix crash with --trace-expand --warn-uninitialized together

Roland Schulz (1):
  FindOpenMP: Fix support for Intel on Windows

Sebastian Holtermann (7):
  Autogen: Protected calls to cmSystemTools::CollapseCombinedPath
  Autogen: Protected calls to cmSystemTools::Split/JoinPath
  Autogen: Protected calls to cmSystemTools::GetFilenameWithoutLastExtension
  Autogen: Protected calls to cmQtAutoGen::SubDirPrefix
  Autogen: Protected calls to cmFilePathChecksum
  Autogen: Use std::istreambuf_iterator for file so string reading
  Autogen: Print moc/uic/rcc output to stdout

---


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.11.1-511-g12139ad

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  12139ad009930ba00c650c03e11f4eff3a081839 (commit)
   via  fbe6cd1596bf280edd49aeb8f981f99d7cd8beb3 (commit)
  from  060b6fc8f6c1722607504c28509d40afb24379a9 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=12139ad009930ba00c650c03e11f4eff3a081839
commit 12139ad009930ba00c650c03e11f4eff3a081839
Merge: 060b6fc fbe6cd1
Author: Brad King 
AuthorDate: Tue Apr 17 09:45:02 2018 -0400
Commit: Brad King 
CommitDate: Tue Apr 17 09:45:02 2018 -0400

Merge branch 'release-3.11'


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.11.0-536-g060b6fc

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  060b6fc8f6c1722607504c28509d40afb24379a9 (commit)
   via  d1d43a6dbf41b3f9841e96c01c7894b050db0cf2 (commit)
  from  886d813b479329023117a5b2022f717c7f6aa64a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=060b6fc8f6c1722607504c28509d40afb24379a9
commit 060b6fc8f6c1722607504c28509d40afb24379a9
Merge: 886d813 d1d43a6
Author: Brad King 
AuthorDate: Tue Apr 17 08:32:42 2018 -0400
Commit: Brad King 
CommitDate: Tue Apr 17 08:32:42 2018 -0400

Merge branch 'release-3.11'


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, release, updated. v3.11.0-26-gd1d43a6

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, release has been updated
   via  d1d43a6dbf41b3f9841e96c01c7894b050db0cf2 (commit)
   via  bbf64794ace7c8a8093d8a42d9d01375e1ab50d6 (commit)
  from  054c849112150452538a1ef7db5b423c5816bca0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:
 bootstrap |6 --
 1 file changed, 4 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


Re: [CMake] Recommandations for public custom macro/functions installation

2018-04-17 Thread Johannes Zarl-Zierl
On Dienstag, 17. April 2018 13:48:39 CEST David Demelier wrote:
> On Tue, 2018-04-17 at 12:25 +0200, Johannes Zarl-Zierl wrote:
> > Just replying to this topic of your message: you may want to
> > reconsider. The
> > cmake gui allows you to group options automatically by prefix. This
> > de-clutters
> > the options considerably.
> 
> I didn't know that! Nice catch. I'll reconsider using prefix then. I've
> usually named my options WITH_FOO, do you recommend to use
> PROJECT_WITH_FOO or WITH_PROJECT_FOO then?

Personally, I prefer PROJECT_WITH_FOO because it also works when I have 
additional options PROJECT_ADDITIONAL_OPTION...


Cheers,
  Johannes


-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake


Re: [CMake] Recommandations for public custom macro/functions installation

2018-04-17 Thread Eric Noulard
2018-04-17 11:58 GMT+02:00 David Demelier :

> Hello,
>
> In my application I have some custom functions that help the process of
> creating executable, libraries, plugins and such.
>
> They don't do magic things but they mostly build, provide installation
> to specific place and optionally build the documentation and install
> them as well. This happens in my project. Since the project is
> extensible, I want to install the libraries **and** those macros so
> users will be able to use them so their plugins get installed in the
> correct place alongside the documentation without much effort.
>
> Example, the user will just write:
>
> irccd_define_plugin(
> SOURCES main.cpp
> DOCS myplugin.md
> )
>
> The problem with that macro, is that it has a conditional to build the
> documentation depending on an option. This is fine in my project since
> the user may build or not build the documentation by setting WITH_DOCS
> to Off.


> Now I wonder how I should handle this option when the macro is
> publicliy installed. The most problematic question is that variables do
> not have namespaces so if the user of my macro also have an option
> WITH_DOCS in its own CMakeLists.txt, this will interfer with the
> installed macro.
>

Add an optional BUILD_DOCS option parameter to your macro  with default to
"False" if not present
so that user cannot call it without knowing.

i.e.

You will call:

irccd_define_plugin(
SOURCES main.cpp
DOCS myplugin.md
BUILD_DOCS ${WITH_DOC}
)

your user may safely call:

irccd_define_plugin(
SOURCES main.cpp
DOCS userplugin.md
)


Another option would be to carry "doc generation option" as a target level
custom property
you can attach to each target (exe, plugins , etc...) created by your macro.

Then your macro may decide to generate doc iff the chosen property is
defined on a per-target basis.

-- 
Eric
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake


Re: [CMake] Recommandations for public custom macro/functions installation

2018-04-17 Thread Craig Scott
On Tue, Apr 17, 2018 at 9:48 PM, David Demelier 
wrote:

> On Tue, 2018-04-17 at 12:25 +0200, Johannes Zarl-Zierl wrote:
> > Just replying to this topic of your message: you may want to
> > reconsider. The
> > cmake gui allows you to group options automatically by prefix. This
> > de-clutters
> > the options considerably.
>
> I didn't know that! Nice catch. I'll reconsider using prefix then. I've
> usually named my options WITH_FOO, do you recommend to use
> PROJECT_WITH_FOO or WITH_PROJECT_FOO then?
>


Definitely go with PROJECT_WITH_FOO. Only the letters up to the first
underscore are used for the grouping in cmake-gui. For larger hierarchical
projects, this grouping feature is pretty important if you want any chance
of keeping the variables manageable in the GUI. The project-specific prefix
is also good protection against name clashes with other parts of the build
(always consider the possibility that your project may one day be used as
part of some larger parent project, pulled in by add_subdirectory()).

-- 
Craig Scott
Melbourne, Australia
https://crascit.com
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, master, updated. v3.11.0-534-g886d813

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  886d813b479329023117a5b2022f717c7f6aa64a (commit)
   via  bbf64794ace7c8a8093d8a42d9d01375e1ab50d6 (commit)
  from  8c2d87dc01c0e2ed7749b5d104f4e4de7b9e5339 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=886d813b479329023117a5b2022f717c7f6aa64a
commit 886d813b479329023117a5b2022f717c7f6aa64a
Merge: 8c2d87d bbf6479
Author: Brad King 
AuthorDate: Tue Apr 17 11:53:08 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:53:16 2018 -0400

Merge topic 'bootstrap_system_libuv_option'

bbf64794ac bootstrap: Add option to enable/disable usage of system libuv

Acked-by: Kitware Robot 
Merge-request: !1971


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bbf64794ace7c8a8093d8a42d9d01375e1ab50d6
commit bbf64794ace7c8a8093d8a42d9d01375e1ab50d6
Author: Kirill Erofeev 
AuthorDate: Tue Apr 17 01:56:14 2018 -0400
Commit: Brad King 
CommitDate: Tue Apr 17 07:44:01 2018 -0400

bootstrap: Add option to enable/disable usage of system libuv

diff --git a/bootstrap b/bootstrap
index 0bee6c5..07552a1 100755
--- a/bootstrap
+++ b/bootstrap
@@ -569,6 +569,8 @@ Configuration:
   --no-system-libarchive  use cmake-provided libarchive library (default)
   --system-librhash   use system-installed librhash library
   --no-system-librhashuse cmake-provided librhash library (default)
+  --system-libuv  use system-installed libuv library
+  --no-system-libuv   use cmake-provided libuv library (default)
 
   --qt-guibuild the Qt-based GUI (requires Qt >= 4.2)
   --no-qt-gui do not build the Qt-based GUI (default)
@@ -803,10 +805,10 @@ while test $# != 0; do
   --init=*) cmake_init_file=`cmake_arg "$1"` ;;
   --system-libs) cmake_bootstrap_system_libs="${cmake_bootstrap_system_libs} 
-DCMAKE_USE_SYSTEM_LIBRARIES=1" ;;
   --no-system-libs) 
cmake_bootstrap_system_libs="${cmake_bootstrap_system_libs} 
-DCMAKE_USE_SYSTEM_LIBRARIES=0" ;;
-  
--system-bzip2|--system-curl|--system-expat|--system-jsoncpp|--system-libarchive|--system-librhash|--system-zlib|--system-liblzma)
+  
--system-bzip2|--system-curl|--system-expat|--system-jsoncpp|--system-libarchive|--system-librhash|--system-zlib|--system-liblzma|--system-libuv)
 lib=`cmake_arg "$1" "--system-"`
 cmake_bootstrap_system_libs="${cmake_bootstrap_system_libs} 
-DCMAKE_USE_SYSTEM_LIBRARY_`cmake_toupper $lib`=1" ;;
-  
--no-system-bzip2|--no-system-curl|--no-system-expat|--no-system-jsoncpp|--no-system-libarchive|--no-system-librhash|--no-system-zlib|--no-system-liblzma)
+  
--no-system-bzip2|--no-system-curl|--no-system-expat|--no-system-jsoncpp|--no-system-libarchive|--no-system-librhash|--no-system-zlib|--no-system-liblzma|--no-system-libuv)
 lib=`cmake_arg "$1" "--no-system-"`
 cmake_bootstrap_system_libs="${cmake_bootstrap_system_libs} 
-DCMAKE_USE_SYSTEM_LIBRARY_`cmake_toupper $lib`=0" ;;
   --qt-gui) cmake_bootstrap_qt_gui="1" ;;

---

Summary of changes:
 bootstrap |6 --
 1 file changed, 4 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


Re: [CMake] Recommandations for public custom macro/functions installation

2018-04-17 Thread David Demelier
On Tue, 2018-04-17 at 12:25 +0200, Johannes Zarl-Zierl wrote:
> Just replying to this topic of your message: you may want to
> reconsider. The 
> cmake gui allows you to group options automatically by prefix. This
> de-clutters 
> the options considerably.

I didn't know that! Nice catch. I'll reconsider using prefix then. I've
usually named my options WITH_FOO, do you recommend to use
PROJECT_WITH_FOO or WITH_PROJECT_FOO then?

-- 
David
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, master, updated. v3.11.0-532-g8c2d87d

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  8c2d87dc01c0e2ed7749b5d104f4e4de7b9e5339 (commit)
   via  dca2347980862d803c182bb5898b5bfaca54aa62 (commit)
   via  cdae12f8f86730e075598118ebe5fd2f11746af7 (commit)
  from  5836c60daada6b323dde32c97c32494a819328c0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8c2d87dc01c0e2ed7749b5d104f4e4de7b9e5339
commit 8c2d87dc01c0e2ed7749b5d104f4e4de7b9e5339
Merge: 5836c60 dca2347
Author: Brad King 
AuthorDate: Tue Apr 17 11:37:50 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:38:28 2018 -0400

Merge topic 'list-TRANSFORM'

dca2347980 list: Add TRANSFORM sub-command
cdae12f8f8 string() Refactoring: creates an helper for REGEX REPLACE

Acked-by: Kitware Robot 
Merge-request: !1938


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=dca2347980862d803c182bb5898b5bfaca54aa62
commit dca2347980862d803c182bb5898b5bfaca54aa62
Author: Marc Chevrier 
AuthorDate: Mon Mar 26 14:32:12 2018 +0200
Commit: Marc Chevrier 
CommitDate: Mon Apr 16 17:11:53 2018 +0200

list: Add TRANSFORM sub-command

Issue: #17823

diff --git a/Help/command/list.rst b/Help/command/list.rst
index 6218a2a..9451d31 100644
--- a/Help/command/list.rst
+++ b/Help/command/list.rst
@@ -151,6 +151,79 @@ REMOVE_DUPLICATES
 
 Removes duplicated items in the list.
 
+TRANSFORM
+"
+
+::
+
+  list(TRANSFORM   []
+[OUTPUT_VARIABLE ])
+
+Transforms the list by applying an action to all or, by specifying a
+, to the selected elements of the list, storing result in-place
+or in the specified output variable.
+
+.. note::
+
+   ``TRANSFORM`` sub-command does not change the number of elements of the
+   list. If a  is specified, only some elements will be changed,
+   the other ones will remain same as before the transformation.
+
+ specify the action to apply to the elements of list.
+The actions have exactly the same semantics as sub-commands of
+:command:`string` command.
+
+The  may be one of:
+
+``APPEND``, ``PREPEND``: Append, prepend specified value to each element of
+the list. ::
+
+  list(TRANSFORM    ...)
+
+``TOUPPER``, ``TOLOWER``: Convert each element of the list to upper, lower
+characters. ::
+
+  list(TRANSFORM   ...)
+
+``STRIP``: Remove leading and trailing spaces from each element of the
+list. ::
+
+  list(TRANSFORM  STRIP ...)
+
+``GENEX_STRIP``: Strip any
+:manual:`generator expressions ` from each
+element of the list. ::
+
+  list(TRANSFORM  GENEX_STRIP ...)
+
+``REPLACE``: Match the regular expression as many times as possible and
+substitute the replacement expression for the match for each element
+of the list
+(Same semantic as ``REGEX REPLACE`` from :command:`string` command). ::
+
+  list(TRANSFORM  REPLACE 
+ ...)
+
+ select which elements of the list will be transformed. Only one
+type of selector can be specified at a time.
+
+The  may be one of:
+
+``AT``: Specify a list of indexes. ::
+
+  list(TRANSFORM   AT  [ ...] ...)
+
+``FOR``: Specify a range with, optionaly, an incerment used to iterate over
+the range. ::
+
+  list(TRANSFORM   FOR   [] ...)
+
+``REGEX``: Specify a regular expression. Only elements matching the regular
+expression will be transformed. ::
+
+  list(TRANSFORM   REGEX  ...)
+
+
 Sorting
 ^^^
 
diff --git a/Help/release/dev/list-transform.rst 
b/Help/release/dev/list-transform.rst
new file mode 100644
index 000..4a6dacc
--- /dev/null
+++ b/Help/release/dev/list-transform.rst
@@ -0,0 +1,5 @@
+list-transform
+--
+
+* The :command:`list` command learned a ``TRANSFORM`` sub-command
+  to apply various string transformation to list's elements.
diff --git a/Source/cmListCommand.cxx b/Source/cmListCommand.cxx
index 821e6d1..31bc1c0 100644
--- a/Source/cmListCommand.cxx
+++ b/Source/cmListCommand.cxx
@@ -5,14 +5,19 @@
 #include "cmsys/RegularExpression.hxx"
 #include 
 #include 
+#include 
 #include 
+#include 
 #include 
+#include 
 #include 
 #include  // required for atoi
 
 #include "cmAlgorithms.h"
+#include "cmGeneratorExpression.h"
 #include "cmMakefile.h"
 #include "cmPolicies.h"
+#include "cmStringReplaceHelper.h"
 #include "cmSystemTools.h"
 #include "cmake.h"
 
@@ -54,6 +59,9 @@ bool cmListCommand::InitialPass(std::vector 
const& args,
   if (subCommand == "REMOVE_DUPLICATES") {
 return 

[Cmake-commits] CMake branch, master, updated. v3.11.0-529-g5836c60

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  5836c60daada6b323dde32c97c32494a819328c0 (commit)
   via  d41e767f2ba538a8c09a9f8b1168c3398ab62113 (commit)
   via  dcec17a31a725c8760ebaeb2b40c3bbecce32d94 (commit)
   via  6ff8e34e5efdd9b621d64a9bc6bc7b436f01ae51 (commit)
   via  054c849112150452538a1ef7db5b423c5816bca0 (commit)
   via  0c7433e874d5f28b15009dbfb1f19ecb34cd71ee (commit)
   via  90cdd06f4c8873d716fed21b2ab123ede50e504f (commit)
   via  cb8c758fdb61ef7a6ad606b4d9e880e955368867 (commit)
   via  3d9d1c9dcfa2d16ef3e14977f62fab8042f108e3 (commit)
   via  c8e98974d8a71ff048eea60e2949382d39d51383 (commit)
  from  8c546287ddadedb7263e9c21115add253c3a82a8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5836c60daada6b323dde32c97c32494a819328c0
commit 5836c60daada6b323dde32c97c32494a819328c0
Merge: d41e767 3d9d1c9
Author: Brad King 
AuthorDate: Tue Apr 17 11:32:38 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:32:53 2018 -0400

Merge topic 'FindOpenAL-std-includes'

3d9d1c9dcf FindOpenAL: Find AL/al.h or OpenAL/al.h in standard include paths

Acked-by: Kitware Robot 
Merge-request: !1963


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d41e767f2ba538a8c09a9f8b1168c3398ab62113
commit d41e767f2ba538a8c09a9f8b1168c3398ab62113
Merge: dcec17a c8e9897
Author: Brad King 
AuthorDate: Tue Apr 17 11:32:04 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:32:11 2018 -0400

Merge topic 'vs-conditional-reference-assembly'

c8e98974d8 VS: Disallow ReferenceOutputAssembly in ProjectReference if not 
possible

Acked-by: Kitware Robot 
Merge-request: !1956


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=dcec17a31a725c8760ebaeb2b40c3bbecce32d94
commit dcec17a31a725c8760ebaeb2b40c3bbecce32d94
Merge: 6ff8e34 054c849
Author: Brad King 
AuthorDate: Tue Apr 17 07:30:09 2018 -0400
Commit: Brad King 
CommitDate: Tue Apr 17 07:30:09 2018 -0400

Merge branch 'release-3.11'


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6ff8e34e5efdd9b621d64a9bc6bc7b436f01ae51
commit 6ff8e34e5efdd9b621d64a9bc6bc7b436f01ae51
Merge: 8c54628 0c7433e
Author: Brad King 
AuthorDate: Tue Apr 17 11:29:28 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:29:33 2018 -0400

Merge topic 'FindOpenMP-Intel-Windows'

0c7433e874 FindOpenMP: Fix support for Intel on Windows

Acked-by: Kitware Robot 
Merge-request: !1957

diff --cc Modules/FindOpenMP.cmake
index e252ba5,1bf589d..329ace1
--- a/Modules/FindOpenMP.cmake
+++ b/Modules/FindOpenMP.cmake
@@@ -242,43 -240,12 +242,34 @@@ function(_OPENMP_GET_FLAGS LANG FLAG_MO
  endforeach()
  set("${OPENMP_LIB_NAMES_VAR}" "${_OPENMP_LIB_NAMES}" PARENT_SCOPE)
else()
- # The Intel compiler on windows has no verbose mode, so we need to 
treat it explicitly
- if("${CMAKE_${LANG}_COMPILER_ID}" STREQUAL "Intel" AND 
"${CMAKE_SYSTEM_NAME}" STREQUAL "Windows")
-   set("${OPENMP_LIB_NAMES_VAR}" "libiomp5md" PARENT_SCOPE)
-   find_library(OpenMP_libiomp5md_LIBRARY
- NAMES "libiomp5md"
- HINTS ${CMAKE_${LANG}_IMPLICIT_LINK_DIRECTORIES}
- CMAKE_FIND_ROOT_PATH_BOTH
- NO_DEFAULT_PATH
-   )
-   mark_as_advanced(OpenMP_libiomp5md_LIBRARY)
- else()
-   set("${OPENMP_LIB_NAMES_VAR}" "" PARENT_SCOPE)
- endif()
+ # We do not know how to extract implicit OpenMP libraries for this 
compiler.
+ # Assume that it handles them automatically, e.g. the Intel Compiler 
on
+ # Windows should put the dependency in its object files.
+ set("${OPENMP_LIB_NAMES_VAR}" "" PARENT_SCOPE)
endif()
break()
 +elseif(CMAKE_${LANG}_COMPILER_ID STREQUAL "AppleClang"
 +  AND CMAKE_${LANG}_COMPILER_VERSION VERSION_GREATER_EQUAL "7.0")
 +
 +  # Check for separate OpenMP library on AppleClang 7+
 +  find_library(OpenMP_libomp_LIBRARY
 +NAMES omp gomp iomp5
 +HINTS ${CMAKE_${LANG}_IMPLICIT_LINK_DIRECTORIES}
 +  )
 +  mark_as_advanced(OpenMP_libomp_LIBRARY)
 +
 +  if(OpenMP_libomp_LIBRARY)
 +try_compile( OpenMP_COMPILE_RESULT_${FLAG_MODE}_${OPENMP_PLAIN_FLAG} 
${CMAKE_BINARY_DIR} ${_OPENMP_TEST_SRC}
 

[Cmake-commits] CMake branch, master, updated. v3.11.0-519-g8c54628

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  8c546287ddadedb7263e9c21115add253c3a82a8 (commit)
   via  d9b4dcc91eefd9d045772619ee79fb6d4a43891e (commit)
   via  eb0498357f35317451dd2c41b68c4d9b52af64fc (commit)
   via  f5f72ff844a3130568dbc62517401c5727fcf9ec (commit)
  from  693021601310ee9ecbeff48fcf13e578f7c1ca42 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8c546287ddadedb7263e9c21115add253c3a82a8
commit 8c546287ddadedb7263e9c21115add253c3a82a8
Merge: d9b4dcc eb04983
Author: Brad King 
AuthorDate: Tue Apr 17 11:19:03 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:19:22 2018 -0400

Merge topic 'implicit-lib-gcceh-file'

eb0498357f Exclude "libgcc_eh" library files from implicit link libraries

Acked-by: Kitware Robot 
Merge-request: !1967


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d9b4dcc91eefd9d045772619ee79fb6d4a43891e
commit d9b4dcc91eefd9d045772619ee79fb6d4a43891e
Merge: 6930216 f5f72ff
Author: Brad King 
AuthorDate: Tue Apr 17 11:18:17 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 07:18:35 2018 -0400

Merge topic 'libuv_version_bump'

f5f72ff844 Explicitly require LibUV 1.10 or higher to build CMake

Acked-by: Kitware Robot 
Merge-request: !1966


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=eb0498357f35317451dd2c41b68c4d9b52af64fc
commit eb0498357f35317451dd2c41b68c4d9b52af64fc
Author: Brad King 
AuthorDate: Mon Apr 16 11:50:05 2018 -0400
Commit: Brad King 
CommitDate: Mon Apr 16 11:56:23 2018 -0400

Exclude "libgcc_eh" library files from implicit link libraries

Extend the fix in commit v3.9.6~1^2 (Restore exclusion of "gcc_eh" from
implicit link libraries, 2017-11-07) to also exclude `gcc_eh` libraries
referenced by absolute path to the library file.

Issue: #17436

diff --git a/Modules/CMakeParseImplicitLinkInfo.cmake 
b/Modules/CMakeParseImplicitLinkInfo.cmake
index 63d18ab..935f92d 100644
--- a/Modules/CMakeParseImplicitLinkInfo.cmake
+++ b/Modules/CMakeParseImplicitLinkInfo.cmake
@@ -142,7 +142,7 @@ function(CMAKE_PARSE_IMPLICIT_LINK_INFO text lib_var 
dir_var fwk_var log_var obj
   # We remove items that are not language-specific.
   set(implicit_libs "")
   foreach(lib IN LISTS implicit_libs_tmp)
-if("x${lib}" MATCHES 
"^x(crt.*\\.o|gcc_eh.*|System.*|.*libclang_rt.*|msvcrt.*|libvcruntime.*|libucrt.*|libcmt.*)$")
+if("x${lib}" MATCHES 
"^x(crt.*\\.o|gcc_eh.*|.*libgcc_eh.*|System.*|.*libclang_rt.*|msvcrt.*|libvcruntime.*|libucrt.*|libcmt.*)$")
   string(APPEND log "  remove lib [${lib}]\n")
 elseif(IS_ABSOLUTE "${lib}")
   get_filename_component(abs "${lib}" ABSOLUTE)
diff --git a/Tests/CMakeTests/ImplicitLinkInfoTest.cmake.in 
b/Tests/CMakeTests/ImplicitLinkInfoTest.cmake.in
index 65487bb..9157c76 100644
--- a/Tests/CMakeTests/ImplicitLinkInfoTest.cmake.in
+++ b/Tests/CMakeTests/ImplicitLinkInfoTest.cmake.in
@@ -349,6 +349,12 @@ set(aix_xlf90_64_libs "xlf90;xlopt;xlf;xlomp_ser;m;c")
 set(aix_xlf90_64_dirs "/usr/lpp/xlf/lib")
 list(APPEND platforms aix_xlf90_64)
 
+# g++ dummy.c -v
+set(aix_g++_text " /prefix/libexec/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/collect2 
-bpT:0x1000 -bpD:0x2000 -btextro /lib/crt0.o 
/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/crtcxa.o 
/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/crtdbase.o 
-L/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0 
-L/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/../../.. /tmp//ccKROJ1f.o 
-lstdc++ -lm -lgcc_s /prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/libgcc.a -lc 
-lgcc_s /prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/libgcc.a")
+set(aix_g++_libs 
"stdc++;m;gcc_s;/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/libgcc.a;c;gcc_s;/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0/libgcc.a")
+set(aix_g++_dirs "/prefix/lib/gcc/powerpc-ibm-aix7.2.0.0/7.2.0;/prefix/lib")
+list(APPEND platforms aix_g++)
+
 #-
 # HP
 

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f5f72ff844a3130568dbc62517401c5727fcf9ec
commit f5f72ff844a3130568dbc62517401c5727fcf9ec
Author: ErofeevK 
AuthorDate: Mon Apr 16 02:48:31 2018 -0400
Commit: Brad King 
CommitDate: Mon Apr 16 11:33:52 2018 -0400

Explicitly require LibUV 1.10 or higher to build CMake

CMake 3.11 now uses 

Re: [CMake] Recommandations for public custom macro/functions installation

2018-04-17 Thread Johannes Zarl-Zierl
Hi David,

On Dienstag, 17. April 2018 11:58:12 CEST David Demelier wrote:
> I personally do not want to prefix all my options in my project with
> the project name prefix, I think that would be a bit ugly, and I do
> want this macro to build and install the documentation.

Just replying to this topic of your message: you may want to reconsider. The 
cmake gui allows you to group options automatically by prefix. This de-clutters 
the options considerably.

On a related note: even without grouping, looking through the options of a 
project in ccmake or cmake-gui is so much easier when they are prefixed (and 
therefore easily identifiable).

Cheers,
  Johannes


-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
https://cmake.org/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.11.1-515-g6774e9c

2018-04-17 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  6774e9cabfb1a9676b787be26cd120e88d6fc21a (commit)
   via  912a6c1cb5949fafe8b17216f162a16261d59d0c (commit)
  from  80d49468de07d194576ead24ff6f2999e1fe32e6 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6774e9cabfb1a9676b787be26cd120e88d6fc21a
commit 6774e9cabfb1a9676b787be26cd120e88d6fc21a
Merge: 80d4946 912a6c1
Author: Craig Scott 
AuthorDate: Tue Apr 17 21:23:39 2018 +
Commit: Kitware Robot 
CommitDate: Tue Apr 17 17:23:47 2018 -0400

Merge topic 'FindOpenSSL-components'

912a6c1cb5 FindOpenSSL: Add component support

Acked-by: Kitware Robot 
Merge-request: !1929


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=912a6c1cb5949fafe8b17216f162a16261d59d0c
commit 912a6c1cb5949fafe8b17216f162a16261d59d0c
Author: Harry Mallon 
AuthorDate: Mon Apr 16 12:38:35 2018 +0100
Commit: Harry Mallon 
CommitDate: Mon Apr 16 12:38:39 2018 +0100

FindOpenSSL: Add component support

diff --git a/Modules/FindOpenSSL.cmake b/Modules/FindOpenSSL.cmake
index c358ff1..d5cd8bc 100644
--- a/Modules/FindOpenSSL.cmake
+++ b/Modules/FindOpenSSL.cmake
@@ -7,6 +7,12 @@
 #
 # Find the OpenSSL encryption library.
 #
+# Optional COMPONENTS
+# ^^^
+#
+# This module supports two optional COMPONENTS: ``Crypto`` and ``SSL``.  Both
+# components have associated imported targets, as described below.
+#
 # Imported Targets
 # 
 #
@@ -23,7 +29,8 @@
 # This module will set the following variables in your project:
 #
 # ``OPENSSL_FOUND``
 #   System has the OpenSSL library.
 # ``OPENSSL_INCLUDE_DIR``
 #   The OpenSSL include directory.
 # ``OPENSSL_CRYPTO_LIBRARY``
@@ -371,28 +378,47 @@ if(OPENSSL_INCLUDE_DIR AND EXISTS 
"${OPENSSL_INCLUDE_DIR}/openssl/opensslv.h")
   endif ()
 endif ()
 
-include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-
 set(OPENSSL_LIBRARIES ${OPENSSL_SSL_LIBRARY} ${OPENSSL_CRYPTO_LIBRARY} )
 
-if (OPENSSL_VERSION)
-  find_package_handle_standard_args(OpenSSL
-REQUIRED_VARS
-  #OPENSSL_SSL_LIBRARY # FIXME: require based on a component request?
-  OPENSSL_CRYPTO_LIBRARY
-  OPENSSL_INCLUDE_DIR
-VERSION_VAR
-  OPENSSL_VERSION
-FAIL_MESSAGE
-  "Could NOT find OpenSSL, try to set the path to OpenSSL root folder in 
the system variable OPENSSL_ROOT_DIR"
-  )
-else ()
-  find_package_handle_standard_args(OpenSSL "Could NOT find OpenSSL, try to 
set the path to OpenSSL root folder in the system variable OPENSSL_ROOT_DIR"
-#OPENSSL_SSL_LIBRARY # FIXME: require based on a component request?
+foreach(_comp IN LISTS OpenSSL_FIND_COMPONENTS)
+  if(_comp STREQUAL "Crypto")
+if(EXISTS "${OPENSSL_INCLUDE_DIR}" AND
+(EXISTS "${OPENSSL_CRYPTO_LIBRARY}" OR
+EXISTS "${LIB_EAY_LIBRARY_DEBUG}" OR
+EXISTS "${LIB_EAY_LIBRARY_RELEASE}")
+)
+  set(OpenSSL_${_comp}_FOUND TRUE)
+else()
+  set(OpenSSL_${_comp}_FOUND FALSE)
+endif()
+  elseif(_comp STREQUAL "SSL")
+if(EXISTS "${OPENSSL_INCLUDE_DIR}" AND
+(EXISTS "${OPENSSL_SSL_LIBRARY}" OR
+EXISTS "${SSL_EAY_LIBRARY_DEBUG}" OR
+EXISTS "${SSL_EAY_LIBRARY_RELEASE}")
+)
+  set(OpenSSL_${_comp}_FOUND TRUE)
+else()
+  set(OpenSSL_${_comp}_FOUND FALSE)
+endif()
+  else()
+message(WARNING "${_comp} is not a valid OpenSSL component")
+set(OpenSSL_${_comp}_FOUND FALSE)
+  endif()
+endforeach()
+unset(_comp)
+
+include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
+find_package_handle_standard_args(OpenSSL
+  REQUIRED_VARS
 OPENSSL_CRYPTO_LIBRARY
 OPENSSL_INCLUDE_DIR
-  )
-endif ()
+  VERSION_VAR
+OPENSSL_VERSION
+  HANDLE_COMPONENTS
+  FAIL_MESSAGE
+"Could NOT find OpenSSL, try to set the path to OpenSSL root folder in the 
system variable OPENSSL_ROOT_DIR"
+)
 
 mark_as_advanced(OPENSSL_INCLUDE_DIR OPENSSL_LIBRARIES)
 
@@ -425,6 +451,7 @@ if(OPENSSL_FOUND)
 IMPORTED_LOCATION_DEBUG "${LIB_EAY_LIBRARY_DEBUG}")
 endif()
   endif()
+
   if(NOT TARGET OpenSSL::SSL AND
   (EXISTS "${OPENSSL_SSL_LIBRARY}" OR
 EXISTS "${SSL_EAY_LIBRARY_DEBUG}" OR

---

Summary of changes:
 Modules/FindOpenSSL.cmake |   65 -
@@ -23,7 +29,8 @@
 #
 # ``OPENSSL_FOUND``
-#   System has the OpenSSL library.
+#   System has the OpenSSL library. If no components are requested it only
+#   requires the crypto library.
 # ``OPENSSL_INCLUDE_DIR``
 #   The OpenSSL include directory.
 1 file changed, 46 insertions(+), 

Re: [cmake-developers] Adding a non-make based generator

2018-04-17 Thread Alexander Neundorf
Hi,

On 2018 M02 14, Wed 22:16:54 CEST Alexander Neundorf wrote:
> On 2018 M02 14, Wed 18:46:52 CET Saeed, Khurram wrote:
> > Thanks Alex.
> > Yes it does support generating the project in the build dir. It also works
> > while generating in a subdir of the source dir. Eclipse version control
> > plugin also works (I am using git).
> 
> Interesting.
> How did you get that working ?
> 
> Let's say the directories look like this:
> 
> src/CMakeLists.txt
> build/CMakeCache.txt
> build/.project
> build/.cproject
> 
> I guess this is what you generate, right ?
> How do you get the source tree into this project ?
> The Eclipse-generator in cmake uses a "linked resource" to the source dir,
> but the version control plugin is not activated for those files.
> According to the Subversion-Plugin developers this is because the source
> files are then outside the "project directory", i.e. no below the directory
> where the .project file is located.
> 
> So I'm really interested how you got that working.
> Can you send the .project and .cproject files for a simple hello-world
> project, built out-of-source ?

any news here ?

Alex

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake


[CMake] Recommandations for public custom macro/functions installation

2018-04-17 Thread David Demelier
Hello,

In my application I have some custom functions that help the process of
creating executable, libraries, plugins and such.

They don't do magic things but they mostly build, provide installation
to specific place and optionally build the documentation and install
them as well. This happens in my project. Since the project is
extensible, I want to install the libraries **and** those macros so
users will be able to use them so their plugins get installed in the
correct place alongside the documentation without much effort.

Example, the user will just write:

irccd_define_plugin(
SOURCES main.cpp
DOCS myplugin.md
)

The problem with that macro, is that it has a conditional to build the
documentation depending on an option. This is fine in my project since
the user may build or not build the documentation by setting WITH_DOCS
to Off.

Now I wonder how I should handle this option when the macro is
publicliy installed. The most problematic question is that variables do
not have namespaces so if the user of my macro also have an option
WITH_DOCS in its own CMakeLists.txt, this will interfer with the
installed macro.

What are your recommandations over this?

I personally do not want to prefix all my options in my project with
the project name prefix, I think that would be a bit ugly, and I do
want this macro to build and install the documentation.

Any advice/comment is welcome.

Regards,

-- 
David
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
https://cmake.org/mailman/listinfo/cmake